@@ -15,6 +15,7 @@ import re
 import threading
 import time
 import urllib.parse as urlparse
+from typing import Optional
 
 import requests
 
@@ -26,7 +27,7 @@ class Session:
 
     def __init__(self, studentID=None, studentPassword=None, manual=False, proxy=None):
         """
-        初始化连接会话，*您可以选择立即登录至一系统，也可以在创建会话后登录。*
+        初始化连接会话，I{您可以选择立即登录至一系统，也可以在创建会话后登录。}
         @param studentID: 若现在登录，则为登录学生的**学号**。
         @param studentPassword: 若现在登录，则为登录学生的**密码**（推荐密码使用str）。
         @param manual: 是否手动输入验证码。若自动输入不成功，请尝试使用手动输入。
@@ -35,13 +36,13 @@ class Session:
         """
         self.id = random.randint(1, 9999)
         self.islogin = False
-        self.studentID = None
+        self.studentID = ""
         self.studentPassword = None
         self.token = None
         self.uid = None
         self.sessionID = None
         self.session = requests.session()
-        self.studentData = models.Student(name="对象创建成功")
+        self.studentData = models.Student("未登录", "", 0, 0, "", "")
 
         self.loginTime = 0
 
@@ -70,7 +71,7 @@ class Session:
     def testConnection(self, url=None):
         """
         测试连接会话是否已经成功建立。
-        @params url: 你可以自定义测试连接时所前往连接的Url（请求方式为get，敬请注意）
+        @param url: 你可以自定义测试连接时所前往连接的Url（请求方式为get，敬请注意）
         @return: 连接成功与否
         """
         if not self.islogin:
@@ -98,9 +99,11 @@ class Session:
     def login(self, studentID=None, studentPassword=None, cookie=None, manual=False):
         """
         登录至一系统。
-        **学号密码登录**：传入学号与密码即可。studentID: 学号; studentPassword: 密码。
-        @params manual:  参数manual用来确认使用自动通过验证码或手动通过验证码。如果您不能成功使用自动模式，请使用手动模式。手动模式仍然存在bug。
-        **cookie登录**：传入cookie即可。
+
+        B{学号密码登录}：传入学号与密码即可。studentID: 学号; studentPassword: 密码。
+
+        B{cookie登录}：传入cookie即可。
+        @param manual: 参数manual用来确认使用自动通过验证码或手动通过验证码。如果您不能成功使用自动模式，请使用手动模式。手动模式可能会发生bug
         @return: 函数会返回cookie，但是会话对象会自动登录，你无需额外操作。
         """
 
@@ -215,8 +218,9 @@ class Session:
                         f"登录失败，1系统返回了不正常的凭据。这通常是由于访问人数过多造成的。频繁出现此错误，则请联系开发者。（notes: json loads succeed but not code 200. The text is '{loginResp3.text}'）")
                 loginResult = loginResult["data"]
                 self.sessionID = loginResult["sessionid"]
-                studentDataSourceObj = loginResult["user"]
-                self.studentData = models.Student(studentDataObject=studentDataSourceObj)
+                sobj = loginResult["user"]
+                self.studentData = models.Student(sobj["name"], sobj["uid"], sobj["sex"], sobj["faculty"],
+                                                  sobj["facultyName"], sobj["grade"])
             except:
                 raise SystemError(
                     f"登录失败，1系统返回了不正常的凭据。这通常是由于访问人数过多造成的。频繁出现此错误，则请联系开发者。（notes: json loads failed while text is '{loginResp3.text}'）")
@@ -276,7 +280,7 @@ class Session:
         return not self.islogin
 
     # 以下是APIs
-    def getSchoolCalender(self) -> dict:
+    def getSchoolCalender(self) -> Optional[dict]:
         """
         获取当前学期的校历。返回数据格式参考文档
         @return: 字典格式的查询结果。若失败，则返回None。
@@ -285,17 +289,17 @@ class Session:
             raise SystemError("请先登录再使用此功能")
         return function.getSchoolCalender(session=self.session)
 
-    def getHolidayByYear(self, year=time.localtime(time.time()).tm_year) -> dict:
+    def getHolidayByYear(self, year=time.localtime(time.time()).tm_year) -> Optional[dict]:
         """
         获取指定年份的假期安排。返回数据格式参考文档
-        @params: 年份。不填则为本年
+        @param year: 年份。不填则为本年
         @return: 字典格式的查询结果。若失败，则返回None。
         """
         if not self.islogin:
             raise SystemError("请先登录再使用此功能")
         return function.getHolidayByYear(year=year, session=self.session)
 
-    def getScore(self) -> models.Scores:
+    def getScore(self) -> Optional[models.Scores]:
         """
         获取本人成绩。返回Scores对象，原始字典在其data属性内。
         @return: Scores对象。若失败，则返回None。
@@ -304,6 +308,18 @@ class Session:
             raise SystemError("请先登录再使用此功能")
         return function.getScore(uid=self.studentID, session=self.session)
 
+    def getRounds(self) -> Optional[tuple]:
+        """
+        获取当前可选课轮次。
+
+        此方法可能存在问题。若出现bug，请直接邮件联系开发者。
+        @return: 包含选课信息具名元组的元组。
+        @rtype: 元组，内容是可以选课的轮次的具名元组。
+        """
+        if not self.islogin:
+            raise SystemError("请先登录再使用此功能")
+        return function.getRounds(session=self.session)
+
     def __str__(self) -> str:
         return self.studentData.name
 
@@ -312,4 +328,4 @@ class Session:
 
 
 if __name__ == "__main__":
-    print(Session("2152955", "ZSYzsy20030810",manual=True))
+    print(Session("", "ZSYzsy20030810", manual=True))
